@@ -111,7 +111,7 @@ MainWindow::MainWindow() : KXmlGuiWindow(),
 	connect(Manager::self(), &Manager::winnerNotify, this, &MainWindow::gameOver);
 	connect(qApp, &QGuiApplication::lastWindowClosed, this, &MainWindow::exitKnights);
 
-	m_themeProvider->discoverThemes("appdata", QLatin1String("themes"));
+	m_themeProvider->discoverThemes("appdata", QStringLiteral("themes"));
 	m_view->drawBoard(m_themeProvider);
 }
 
@@ -139,7 +139,7 @@ void MainWindow::activePlayerChanged() {
 void MainWindow::setupDocks() {
 	// clock dock
 	m_clockDock = new QDockWidget(i18n("Clock"), this);
-	m_clockDock->setObjectName(QLatin1String("ClockDockWidget"));       // for QMainWindow::saveState()
+	m_clockDock->setObjectName(QStringLiteral("ClockDockWidget"));       // for QMainWindow::saveState()
 	m_playerClock = new ClockWidget(this);
 	m_clockDock->setWidget(m_playerClock);
 	m_clockDock->setFeatures(QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
@@ -149,25 +149,25 @@ void MainWindow::setupDocks() {
 
 	// console dock for black
 	m_bconsoleDock = new QDockWidget();
-	m_bconsoleDock->setObjectName(QLatin1String("BlackConsoleDockWidget"));
+	m_bconsoleDock->setObjectName(QStringLiteral("BlackConsoleDockWidget"));
 	m_bconsoleDock->setFeatures(QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
 	addDockWidget(Qt::LeftDockWidgetArea, m_bconsoleDock);
 
 	// console dock for white
 	m_wconsoleDock = new QDockWidget();
-	m_wconsoleDock->setObjectName(QLatin1String("WhiteConsoleDockWidget"));
+	m_wconsoleDock->setObjectName(QStringLiteral("WhiteConsoleDockWidget"));
 	m_wconsoleDock->setFeatures(QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
 	addDockWidget(Qt::LeftDockWidgetArea, m_wconsoleDock);
 
 	// chat dock
 	m_chatDock = new QDockWidget();
-	m_chatDock->setObjectName(QLatin1String("ChatDockWidget"));
+	m_chatDock->setObjectName(QStringLiteral("ChatDockWidget"));
 	m_chatDock->setFeatures(QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
 	addDockWidget(Qt::LeftDockWidgetArea, m_chatDock);
 
 	// history dock
 	m_historyDock = new QDockWidget();
-	m_historyDock->setObjectName(QLatin1String("HistoryDockWidget"));
+	m_historyDock->setObjectName(QStringLiteral("HistoryDockWidget"));
 	m_historyDock->setFeatures(QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
 	m_historyDock->setWindowTitle(i18n("Move History"));
 	m_historyDock->setWidget(new HistoryWidget);
@@ -187,72 +187,72 @@ void MainWindow::setupActions() {
 	m_saveAsAction->setEnabled(false);
 	KStandardGameAction::load(this, SLOT(fileLoad()), actionCollection());
 
-	m_resignAction = actionCollection()->addAction(QLatin1String("resign"), this, SLOT(resign()));
+	m_resignAction = actionCollection()->addAction(QStringLiteral("resign"), this, SLOT(resign()));
 	m_resignAction->setText(i18n("Resign"));
 	m_resignAction->setToolTip(i18n("Admit your inevitable defeat"));
-	m_resignAction->setIcon(QIcon::fromTheme(QLatin1String("flag-red")));
+	m_resignAction->setIcon(QIcon::fromTheme(QStringLiteral("flag-red")));
 	m_resignAction->setEnabled(false);
 
-	m_undoAction = actionCollection()->addAction(QLatin1String("move_undo"), this, SLOT(undo()));
+	m_undoAction = actionCollection()->addAction(QStringLiteral("move_undo"), this, SLOT(undo()));
 	m_undoAction->setText(i18n("Undo"));
 	m_undoAction->setToolTip(i18n("Take back your last move"));
-	m_undoAction->setIcon(QIcon::fromTheme(QLatin1String("edit-undo")));
+	m_undoAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-undo")));
 	connect(Manager::self(), &Manager::undoPossible, m_undoAction, &QAction::setEnabled);
 	m_undoAction->setEnabled(false);
 
-	m_redoAction = actionCollection()->addAction(QLatin1String("move_redo"), this, SLOT(redo()));
+	m_redoAction = actionCollection()->addAction(QStringLiteral("move_redo"), this, SLOT(redo()));
 	m_redoAction->setText(i18n("Redo"));
 	m_redoAction->setToolTip(i18n("Repeat your last move"));
-	m_redoAction->setIcon(QIcon::fromTheme(QLatin1String("edit-redo")));
+	m_redoAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-redo")));
 	connect(Manager::self(), &Manager::redoPossible, m_redoAction, &QAction::setEnabled);
 	m_redoAction->setEnabled(false);
 	m_redoAction->setVisible(false);
 
-	m_drawAction = actionCollection()->addAction(QLatin1String("propose_draw"), Manager::self(), SLOT(offerDraw()));
+	m_drawAction = actionCollection()->addAction(QStringLiteral("propose_draw"), Manager::self(), SLOT(offerDraw()));
 	m_drawAction->setText(i18n("Offer &Draw"));
 	m_drawAction->setToolTip(i18n("Offer a draw to your opponent"));
-	m_drawAction->setIcon(QIcon::fromTheme(QLatin1String("flag-blue")));
+	m_drawAction->setIcon(QIcon::fromTheme(QStringLiteral("flag-blue")));
 	m_drawAction->setEnabled(false);
 
-	m_adjournAction = actionCollection()->addAction(QLatin1String("adjourn"), Manager::self(), SLOT(adjourn()));
+	m_adjournAction = actionCollection()->addAction(QStringLiteral("adjourn"), Manager::self(), SLOT(adjourn()));
 	m_adjournAction->setText(i18n("Adjourn"));
 	m_adjournAction->setToolTip(i18n("Continue this game at a later time"));
-	m_adjournAction->setIcon(QIcon::fromTheme(QLatin1String("document-save")));
+	m_adjournAction->setIcon(QIcon::fromTheme(QStringLiteral("document-save")));
 	m_adjournAction->setEnabled(false);
 
-	QAction* abortAction = actionCollection()->addAction(QLatin1String("abort"), Manager::self(), SLOT(abort()));
+	QAction* abortAction = actionCollection()->addAction(QStringLiteral("abort"), Manager::self(), SLOT(abort()));
 	abortAction->setText(i18n("Abort"));
 	abortAction->setToolTip(i18n("End the game immediately"));
-	abortAction->setIcon(QIcon::fromTheme(QLatin1String("dialog-cancel")));
+	abortAction->setIcon(QIcon::fromTheme(QStringLiteral("dialog-cancel")));
 	abortAction->setEnabled(false);
 
-	KToggleAction* clockAction = new KToggleAction(QIcon::fromTheme(QLatin1String("clock")), i18n("Show Clock"), actionCollection());
-	actionCollection()->addAction(QLatin1String("show_clock"), clockAction);
+	KToggleAction* clockAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("clock")), i18n("Show Clock"), actionCollection());
+	actionCollection()->addAction(QStringLiteral("show_clock"), clockAction);
 	connect(clockAction, &KToggleAction::triggered, m_clockDock, &QDockWidget::setVisible);
 	connect(clockAction, &KToggleAction::triggered, this, &MainWindow::setShowClockSetting);
 	clockAction->setVisible(false);
 
-	KToggleAction* historyAction = new KToggleAction(QIcon::fromTheme(QLatin1String("view-history")), i18n("Show History"), actionCollection());
-	actionCollection()->addAction(QLatin1String("show_history"), historyAction);
+	KToggleAction* historyAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("view-history")), i18n("Show History"), actionCollection());
+	actionCollection()->addAction(QStringLiteral("show_history"), historyAction);
 	connect(historyAction, &KToggleAction::triggered, m_historyDock, &QDockWidget::setVisible);
 	connect(historyAction, &KToggleAction::triggered, this, &MainWindow::setShowHistorySetting);
 	historyAction->setVisible(true);
 	historyAction->setChecked(Settings::showHistory());
 
-	KToggleAction* wconsoleAction = new KToggleAction(QIcon::fromTheme(QLatin1String("utilities-terminal")), i18n("Show White Console"), actionCollection());
-	actionCollection()->addAction(QLatin1String("show_console_white"), wconsoleAction);
+	KToggleAction* wconsoleAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("utilities-terminal")), i18n("Show White Console"), actionCollection());
+	actionCollection()->addAction(QStringLiteral("show_console_white"), wconsoleAction);
 	connect(wconsoleAction, &KToggleAction::triggered, m_wconsoleDock, &QDockWidget::setVisible);
 	connect(wconsoleAction, &KToggleAction::triggered, this, &MainWindow::setShowConsoleSetting);
 	wconsoleAction->setVisible(false);
 
-	KToggleAction* bconsoleAction = new KToggleAction(QIcon::fromTheme(QLatin1String("utilities-terminal")), i18n("Show Black Console"), actionCollection());
-	actionCollection()->addAction(QLatin1String("show_console_black"), bconsoleAction);
+	KToggleAction* bconsoleAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("utilities-terminal")), i18n("Show Black Console"), actionCollection());
+	actionCollection()->addAction(QStringLiteral("show_console_black"), bconsoleAction);
 	connect(bconsoleAction, &KToggleAction::triggered, m_bconsoleDock, &QDockWidget::setVisible);
 	connect(bconsoleAction, &KToggleAction::triggered, this, &MainWindow::setShowConsoleSetting);
 	bconsoleAction->setVisible(false);
 
-	KToggleAction* chatAction = new KToggleAction(QIcon::fromTheme(QLatin1String("meeting-attending")), i18n("Show Chat"), actionCollection());
-	actionCollection()->addAction(QLatin1String("show_chat"), chatAction);
+	KToggleAction* chatAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("meeting-attending")), i18n("Show Chat"), actionCollection());
+	actionCollection()->addAction(QStringLiteral("show_chat"), chatAction);
 	connect(chatAction, &KToggleAction::triggered, m_chatDock, &QDockWidget::setVisible);
 	connect(chatAction, &KToggleAction::triggered, this, &MainWindow::setShowChatSetting);
 	chatAction->setVisible(false);
@@ -281,6 +281,7 @@ void MainWindow::fileNew() {
 
 	m_saveAction->setEnabled(false);
 	m_saveAsAction->setEnabled(false);
+	m_fileName = QString();
 }
 
 void MainWindow::fileLoad() {
@@ -316,15 +317,13 @@ void MainWindow::fileLoad() {
 
 void MainWindow::protocolInitSuccesful() {
 	qCDebug(LOG_KNIGHTS) << "Show Clock:" << Settings::showClock() << "Show Console:" << Settings::showConsole();
-	QString whiteName = Protocol::white()->playerName();
-	QString blackName = Protocol::black()->playerName();
 	updateCaption();
 
 	// show clock action button if timer active
 	// show clock dock widget if timer active and configuration file entry has visible = true
 	bool showClock = false;
 	if(Manager::self()->timeControlEnabled(White) || Manager::self()->timeControlEnabled(Black)) {
-		actionCollection()->action(QLatin1String("show_clock"))->setVisible(true);
+		actionCollection()->action(QStringLiteral("show_clock"))->setVisible(true);
 		m_playerClock->setPlayerName(White, Protocol::white()->playerName());
 		m_playerClock->setPlayerName(Black, Protocol::black()->playerName());
 		m_playerClock->setTimeLimit(White, Manager::self()->timeLimit(White));
@@ -332,12 +331,12 @@ void MainWindow::protocolInitSuccesful() {
 		showClock = Settings::showClock();
 	}
 	m_clockDock->setVisible(showClock);
-	actionCollection()->action(QLatin1String("show_clock"))->setChecked(showClock);
+	actionCollection()->action(QStringLiteral("show_clock"))->setChecked(showClock);
 
 	//history dock
 	bool showHistory = Settings::showHistory();
 	m_historyDock->setVisible(showHistory);
-	actionCollection()->action(QLatin1String("show_history"))->setChecked(showHistory);
+	actionCollection()->action(QStringLiteral("show_history"))->setChecked(showHistory);
 
 	if ( !(Protocol::white()->supportedFeatures() & Protocol::Undo &&
 		Protocol::black()->supportedFeatures() & Protocol::Undo) ) {
@@ -367,36 +366,36 @@ void MainWindow::protocolInitSuccesful() {
 	// show console action button if protocol allows a console
 	// show console dock widget if protocol allows and configuration file entry has visible = true
 	// finally, hide any dock widget not needed - in case it is still active from previous game
-	actionCollection()->action(QLatin1String("show_console_white"))->setVisible(false);
-	actionCollection()->action(QLatin1String("show_console_black"))->setVisible(false);
-	actionCollection()->action(QLatin1String("show_chat"))->setVisible(false);
+	actionCollection()->action(QStringLiteral("show_console_white"))->setVisible(false);
+	actionCollection()->action(QStringLiteral("show_console_black"))->setVisible(false);
+	actionCollection()->action(QStringLiteral("show_chat"))->setVisible(false);
 	QList<Protocol::ToolWidgetData> list;
 	list << Protocol::black()->toolWidgets();
 	list << Protocol::white()->toolWidgets();
-	for (const auto& data : list) {
+	for (const auto& data : qAsConst(list)) {
 		switch(data.type) {
 		case Protocol::ConsoleToolWidget:
 			if(data.owner == White) {
 				m_wconsoleDock->setWindowTitle(data.title);
 				m_wconsoleDock->setWidget(data.widget);
-				actionCollection()->action(QLatin1String("show_console_white"))->setVisible(true);
+				actionCollection()->action(QStringLiteral("show_console_white"))->setVisible(true);
 				if(Settings::showConsole()) {
 					m_wconsoleDock->setVisible(true);
-					actionCollection()->action(QLatin1String("show_console_white"))->setChecked(true);
+					actionCollection()->action(QStringLiteral("show_console_white"))->setChecked(true);
 				} else {
 					m_wconsoleDock->setVisible(false);
-					actionCollection()->action(QLatin1String("show_console_white"))->setChecked(false);
+					actionCollection()->action(QStringLiteral("show_console_white"))->setChecked(false);
 				}
 			} else {
 				m_bconsoleDock->setWindowTitle(data.title);
 				m_bconsoleDock->setWidget(data.widget);
-				actionCollection()->action(QLatin1String("show_console_black"))->setVisible(true);
+				actionCollection()->action(QStringLiteral("show_console_black"))->setVisible(true);
 				if(Settings::showConsole()) {
 					m_bconsoleDock->setVisible(true);
-					actionCollection()->action(QLatin1String("show_console_black"))->setChecked(true);
+					actionCollection()->action(QStringLiteral("show_console_black"))->setChecked(true);
 				} else {
 					m_bconsoleDock->setVisible(false);
-					actionCollection()->action(QLatin1String("show_console_black"))->setChecked(false);
+					actionCollection()->action(QStringLiteral("show_console_black"))->setChecked(false);
 				}
 			}
 			break;
@@ -404,13 +403,13 @@ void MainWindow::protocolInitSuccesful() {
 		case Protocol::ChatToolWidget:
 			m_chatDock->setWindowTitle(data.title);
 			m_chatDock->setWidget(data.widget);
-			actionCollection()->action(QLatin1String("show_chat"))->setVisible(true);
+			actionCollection()->action(QStringLiteral("show_chat"))->setVisible(true);
 			if(Settings::showChat()) {
 				m_chatDock->setVisible(true);
-				actionCollection()->action(QLatin1String("show_chat"))->setChecked(true);
+				actionCollection()->action(QStringLiteral("show_chat"))->setChecked(true);
 			} else {
 				m_chatDock->setVisible(false);
-				actionCollection()->action(QLatin1String("show_chat"))->setChecked(false);
+				actionCollection()->action(QStringLiteral("show_chat"))->setChecked(false);
 			}
 			break;
 
@@ -418,11 +417,11 @@ void MainWindow::protocolInitSuccesful() {
 			break;
 		}
 	}
-	if(!actionCollection()->action(QLatin1String("show_console_white"))->isVisible())
+	if(!actionCollection()->action(QStringLiteral("show_console_white"))->isVisible())
 		m_wconsoleDock->hide();
-	if(!actionCollection()->action(QLatin1String("show_console_black"))->isVisible())
+	if(!actionCollection()->action(QStringLiteral("show_console_black"))->isVisible())
 		m_bconsoleDock->hide();
-	if(!actionCollection()->action(QLatin1String("show_chat"))->isVisible())
+	if(!actionCollection()->action(QStringLiteral("show_chat"))->isVisible())
 		m_chatDock->hide();
 
 	Manager::self()->startGame();
@@ -450,17 +449,17 @@ void MainWindow::protocolError(Protocol::ErrorCode errorCode, const QString& err
 }
 
 void MainWindow::optionsPreferences() {
-	if(KConfigDialog::showDialog(QLatin1String("settings")))
+	if(KConfigDialog::showDialog(QStringLiteral("settings")))
 		return;
-	KConfigDialog *dialog = new KConfigDialog(this, QLatin1String("settings"), Settings::self());
+	KConfigDialog *dialog = new KConfigDialog(this, QStringLiteral("settings"), Settings::self());
 	QWidget *generalSettingsDlg = new QWidget;
 	ui_prefs_base.setupUi(generalSettingsDlg);
 
-	dialog->addPage(generalSettingsDlg, i18n("General"), QLatin1String("games-config-options"));
+	dialog->addPage(generalSettingsDlg, i18n("General"), QStringLiteral("games-config-options"));
 	connect(dialog, &KConfigDialog::settingsChanged, m_view, &KnightsView::settingsChanged);
 
 	EngineSettings* engineSettings = new EngineSettings(this);
-	dialog->addPage(engineSettings, i18n("Computer Engines"), QLatin1String("computer"));
+	dialog->addPage(engineSettings, i18n("Computer Engines"), QStringLiteral("computer"));
 	connect(dialog, &KConfigDialog::accepted, engineSettings, &EngineSettings::save);
 
 	//FIXME: the accessibility page doesn't seem to be used at the moment.
@@ -470,7 +469,7 @@ void MainWindow::optionsPreferences() {
 // 	dialog->addPage(accessDlg, i18n("Accessibility"), QLatin1String("preferences-desktop-accessibility"));
 
 	QWidget* themeDlg = new KgThemeSelector(m_themeProvider, KgThemeSelector::EnableNewStuffDownload, dialog);
-	dialog->addPage(themeDlg, i18n("Theme"), QLatin1String("games-config-theme"));
+	dialog->addPage(themeDlg, i18n("Theme"), QStringLiteral("games-config-theme"));
 	dialog->setAttribute(Qt::WA_DeleteOnClose);
 
 	dialog->show();
@@ -590,9 +589,9 @@ void MainWindow::setShowHistorySetting(bool value) {
 }
 
 void MainWindow::setShowConsoleSetting() {
-	if((actionCollection()->action(QLatin1String("show_console_white"))->isChecked()) && (actionCollection()->action(QLatin1String("show_console_white"))->isVisible()))
+	if((actionCollection()->action(QStringLiteral("show_console_white"))->isChecked()) && (actionCollection()->action(QStringLiteral("show_console_white"))->isVisible()))
 		Settings::setShowConsole(true);
-	else if((actionCollection()->action(QLatin1String("show_console_black"))->isChecked()) && (actionCollection()->action(QLatin1String("show_console_black"))->isVisible()))
+	else if((actionCollection()->action(QStringLiteral("show_console_black"))->isChecked()) && (actionCollection()->action(QStringLiteral("show_console_black"))->isVisible()))
 		Settings::setShowConsole(true);
 	else
 		Settings::setShowConsole(false);
